Bruggeman: Analytical Solutions of Geohydrological Problems
===========================================================

This repository contains implementations of Bruggeman's analytical solutions in Python.

The philosphy behind this repository is to collect implementations of
analytical solutions so they are readily available for use in projects or for
benchmarking other computations or models.


.. toctree::
   :maxdepth: 1
   :caption: Contents:

   Examples <examples/index>